package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.30.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.30.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````(`*``!````T!D!`#0```!PD0````0`!30`(``)
M`"@`'``;``$``'`T@P``-(,!`#2#`0`(````"`````0````$````!@```#0`
M```T``$`-``!`"`!```@`0``!`````0````#````5`$``%0!`0!4`0$`&0``
M`!D````$`````0````$````````````!`````0!`@P``0(,```4```````$`
M`0```+B-``"XC0(`N(T"`%@"``"$$@``!@```````0`"````V(T``-B-`@#8
MC0(`$`$``!`!```&````!`````0```!P`0``<`$!`'`!`0!$````1`````0`
M```$````4>5T9```````````````````````````!@```!````!2Y71DN(T`
M`+B-`@"XC0(`2`(``$@"```$`````0```"]L:6(O;&0M;&EN=7@M87)M:&8N
M<V\N,P`````$````%`````,```!'3E4`7M^\8K);9#)HRR$AD!;A_.II4CL$
M````$`````$```!'3E4```````,````"`````````&$````$````(`````H`
M``"H$A```D01(``"0`!6`'`8P@@`,`@`$!$``!`"`"@`````````2`(@"@`*
M``2$`JA`"`5@80"$"#Y"/)<``0`()%B`!(E@#)-X"4):0$0`0``!`$()`$"`
MC,"$```0D!"#"0`(`1"`@4!`P@F`+$"8`D$`(,`@!`D`D``D#I-&0`0`````
M````!0````8````(``````````````````````````D````+````#`````X`
M```/````$````!(````5`````````````````````````!<````:````&P``
M`!\````@````(0```"(`````````(P```"4````I`````````"L`````````
M`````"P````M````+@```"\`````````,P```#0````V````-P``````````
M````.````#L````\`````````#T````^````0````$(```!%`````````$<`
M``!(````20```$H`````````2P``````````````````````````````````
M`$P```!-`````````$\`````````40```%,```!5````````````````````
M`````%8```!:````6P```%P`````````7@``````````````8```````````
M````8@```&0```!E````9@```&D```!?EI,<HUKOD%;;DQS#CH?_#3J7"])1
M!(2!=((->_!*:W94/)3-/PRO]R/.((D'<-,@=+`"U634?&:OS&8N3CWVV_<`
M7@:DA_\!KS3HSDJN_\[>1RWAIP(*XT?&`<8.X#T^?I9\[#^0`FUSA<5K&IY0
MQ8D%D&&8[Q(!(_FD0OK7AYV[DQQ"1=7L4.X1XX;YG(%][1$/NI63'%N:.P]!
M39U\I]VC:UGOEWDY\HL<#!3BG@0RI86B`O89V\WCGONA;&#(.4`?,V+;[3^>
M0D3I^\/"2B)]_PJ*$%?MWI,<K4OCP-EQ6!PKT.$B&I_6O2T.L7-8.T`?P^4_
M+)@BU&BZXY)\(?_D#HJ8W<)O>FGZDZT$8C?C\,%#\N_(WX4@3U>DFY;%N9Q`
M4!M]7S&X@@V^VE<;LP&+;[S02WUW;^-P:@E#UI\BQZ@A8F0'?JF<FV+0^H+L
M+/:+:W^:?(?PEGP5C"7,[@M1^?/;TQV0=8(-0V9+$#RM.0T7ZEKQIIN3'*/@
M^TE7DEI2_=+O#V[%WQ]\D!#I+=_^2"[%F[;)U;)Q````````````````````
M`!$``````````````"`````M```````````````@````/```````````````
M(````"(#`````````````!(````+`@`````````````2````D`(`````````
M````$@```&T"`````````````!(````9!````)`"```````@`!<`DP$`````
M````````$@```&8"`````````````!(```"#`0``"!4!```````2````G@,`
M`!"0`@``````$``8`"D"`````````````!(```!+`@`````````````2````
M600```R0`@`$````$0`7`-,"`````````````!(```#1!```D"\!`'0#```2
M``T`\P,``+@D`0```0``$@`-`"D#`````````````!(````Q`@``````````
M```2````Y`(`````````````$@```-L#```\H`(``````!``&`"^`P``````
M```````2````_P,``,0H`0#,!@``$@`-`#,$``"<(0$`S````!(`#0#F`P``
MD"0!`"@````2``T`6`(`````````````$@```"0"`````````````!(```!<
M`0`````````````2````P`(`````````````$@```'T$```P0P$`1`$``!(`
M#0`\`P``$)`"``0````A`!@`$P(`````````````$@```/0!````````````
M`!(````,!```\$$!`$`!```2``T`@@(`````````````$@```-,#```0D`(`
M`````!``%P"=`@`````````````2````<P```"07`0``````$@```&`"````
M`````````!(```#T`@`````````````2````!0(`````````````$@```.\!
M`````````````!(````]`P``$)`"``0````A`!@`:`0``#R@`@``````$``8
M`-T"```@D`(`!````!$`&`!]`P``U$0!``0````2``T`9P$`````````````
M$@```$,!`````````````!(```!)!```=$0!`&`````2``T`J`0``/0G`0#0
M````$@`-`#H"`````````````!(````=!```T!D!```````2``T`DP``````
M````````$@```)\``````````````!(```"R`@`````````````2````XP``
M`!B0`@`!````$0`8`'L"`````````````!(````D!```]$0!``0````1``\`
MAP0``!"0`@``````$``8`/L"`````````````!(````3`P`````````````2
M````5@``````````````$@```/```````````````!(```"3!```%"$!`#0`
M```2``T`#`$`````````````$@```&,$```\H`(``````!``&`";!```;"(!
M`"0"```2``T`M```````````````$@```$4#`````````````!(```#;`0``
M```````````2````=0$`````````````$@```,(``````````````!(```#4
M```````````````2`````0$``!20`@`$````$0`8`#L#```0D`(`!````!$`
M&``U`0`````````````2````B0(`````````````$@```-H#```\H`(`````
M`!``&`"Z!```6"<!`(0````2``T`A```````````````$@```,L"````````
M`````!(````7!````)`"```````0`!<`!0,`````````````$@```&L#``#`
MC0(`!````!$`%`"L`P``W"<!`!@````2``T`L0$`````````````$@```)X!
M`````````````!(````V`P``J!<!`"@"```2``T`$0$`````````````$@``
M`,@$``!D00$`C````!(`#0#K`@`````````````2````O`$``,2-`@`3````
M$0`4`*L"`````````````!(```"7`@`````````````2````J@$`````````
M````$@```!L#`````````````!(```!T`@`````````````2````<`0``+@E
M`0"@`0``$@`-`!8!`````````````!(```!2`@`````````````2````QP,`
M``0S`0!X````$@`-`&0``````````````!(```!3`0`````````````2````
MC0,``&@B`0`$````$@`-`"(!``"L%@$``````!(`````;&EB<&5R;"YS;RXU
M+C,P`%])5$U?9&5R96=I<W1E<E1-0VQO;F5486)L90!?7V=M;VY?<W1A<G1?
M7P!?251-7W)E9VES=&5R5$U#;&]N951A8FQE`%!E<FQ?<WES7W1E<FT`4&5R
M;%]S>7-?:6YI=#,`4&5R;%]A=&9O<FM?;&]C:P!P97)L7V-O;G-T<G5C=`!0
M97)L7V=E=%]S=@!097)L7V-R;V%K7VYO8V]N=&5X=`!097)L7V%V7W-H:69T
M`%!E<FQ?<W9?,G!V7V9L86=S`%!E<FQ?<W9?<V5T<'9N`%!,7V1O7W5N9'5M
M<`!097)L7VYE=UA37V9L86=S`%!,7W1H<E]K97D`<&5R;%]F<F5E`%!E<FQ?
M;6=?<V5T`%!E<FQ?871F;W)K7W5N;&]C:P!097)L7W-V7W-E='!V`%!E<FQ?
M9W9?9F5T8VAP=@!P97)L7W)U;@!097)L7VYE=UA3`'!E<FQ?9&5S=')U8W0`
M4&5R;%]A=E]F971C:`!B;V]T7T1Y;F%,;V%D97(`<&5R;%]P87)S90!097)L
M7W-A9F5S>7-M86QL;V,`<&5R;%]A;&QO8P!03%]M96UO<GE?=W)A<`!L:6)P
M=&AR96%D+G-O+C``<'1H<F5A9%]G971S<&5C:69I8P!R96%D`%]?97)R;F]?
M;&]C871I;VX`8VQO<V4`;'-E96LV-`!O<&5N-C0`;&EB8RYS;RXV`&5X:70`
M<W1R;F-M<`!C;&]S961I<@!?7W-T86-K7V-H:U]F86EL`'5N;&EN:P!M:V1I
M<@!R96%L;&]C`&%B;W)T`&UE;6-H<@!G971P:60`<W1R9'5P`'-T<G1O:P!S
M=')L96X`;65M<V5T`'-T<G-T<@!R;61I<@!?7V9P<FEN=&9?8VAK`&UE;6-P
M>0!?7W-T<FYC<'E?8VAK`%]?;'AS=&%T-C0`;W!E;F1I<@!?7WAS=&%T-C0`
M<W1D97)R`&=E='5I9`!R96%D;&EN:P!S=')C:'(`<F5A9&1I<C8T`%]?<W!R
M:6YT9E]C:&L`;65M;6]V90!A8V-E<W,`<W1R8VUP`%]?;&EB8U]S=&%R=%]M
M86EN`%]?96YV:7)O;@!?7W)E9VES=&5R7V%T9F]R:P!L9"UL:6YU>"UA<FUH
M9BYS;RXS`%]?<W1A8VM?8VAK7V=U87)D`%]?;&EB8U]C<W5?9FEN:0!P87)?
M8W5R<F5N=%]E>&5C`%]?8G-S7W-T87)T7U\`9V5T7W5S97)N86UE7V9R;VU?
M9V5T<'=U:60`<&%R7V-L96%N=7``7V5D871A`%]?8G-S7V5N9%]?`'!A<E]B
M87-E;F%M90!P87)?9&ER;F%M90!P87)?;6MT;7!D:7(`<VAA7W5P9&%T90!?
M7V1A=&%?<W1A<G0`7TE/7W-T9&EN7W5S960`<&%R7V-U<G)E;G1?97AE8U]P
M<F]C`%]?;&EB8U]C<W5?:6YI=`!M>5]P87)?<&P`7V5N9`!?7V5N9%]?`'!A
M<E]I;FET7V5N=@!S:&%?9FEN86P`7U]B<W-?<W1A<G0`>'-?:6YI=`!P87)?
M9FEN9'!R;V<`<&%R7W-E='5P7VQI8G!A=&@`<&%R7V5N=E]C;&5A;@!S:&%?
M:6YI=`!84U]);G1E<FYA;'-?4$%27T)/3U0`1TQ)0D-?,BXT````````````
M``(``P`"``(``0````(````!``(``@`!``(``0`!``(``@`"``$``@`!``$`
M`0`"``(````"``$``@`#``,``0`"``$``@````(``@`#``,``@`!``(``0``
M`````0`!``(``0```````@````(``0`!``(``@```````0````$``0````(`
M`P````````````(````"``$``0````(``0`"``0``0```````0`"``$``@``
M``(``@`"``(``@`!`````@`!```````!`````0`!`%<#```0````(````!1I
M:0T```0`YP0````````!``$`RP$``!`````@````%&EI#0```P#G!```````
M``$``0`:`@``$``````````4:6D-```"`.<$````````^(\"`!4"``#`C0(`
M%%4``,2-`@`470``$)`"`!1,```4D`(`%$L``!B0`@`4.0``()`"`!0N``#T
MC@(`%@8``/B.`@`6!```_(X"`!87````CP(`%BL```2/`@`6%0``"(\"`!8^
M```,CP(`%EH``!"/`@`610``%(\"`!9>```8CP(`%@L``!R/`@`67P``((\"
M`!91```DCP(`%D(``"B/`@`6.```+(\"`!9B```PCP(`%C0``#2/`@`61@``
M.(\"`!8.```\CP(`%AL``$"/`@`6,```1(\"`!9-``!(CP(`%EP``$R/`@`6
M20``4(\"`!97``!4CP(`%@4``%B/`@`66```7(\"`!92``!@CP(`%B$``&2/
M`@`68```:(\"`!83``!LCP(`%C$``'"/`@`6`@``=(\"`!8'``!XCP(`%AP`
M`'R/`@`6)```@(\"`!9G``"$CP(`%BD``(B/`@`6-@``C(\"`!8B``"0CP(`
M%E0``)2/`@`6-P``F(\"`!8=``"<CP(`%F4``*"/`@`63@``I(\"`!9J``"H
MCP(`%C\``*R/`@`69```L(\"`!8)``"TCP(`%B8``+B/`@`60```O(\"`!8*
M``#`CP(`%F$``,2/`@`6.@``R(\"`!9(``#,CP(`%B<``-"/`@`6/0``U(\"
M`!9*``#8CP(`%F@``-R/`@`6$```X(\"`!8-``#DCP(`%B@``.B/`@`6*@``
M[(\"`!8>``#PCP(`%A0``/2/`@`61P``"$`MZ6$!`.L(@+WH!.`MY03@G^4.
MX(_@"/"^Y5!Z`0``QH_B%\J,XE#ZO.4`QH_B%\J,XDCZO.4`QH_B%\J,XD#Z
MO.4`QH_B%\J,XCCZO.4`QH_B%\J,XC#ZO.4`QH_B%\J,XBCZO.4`QH_B%\J,
MXB#ZO.4`QH_B%\J,XACZO.4`QH_B%\J,XA#ZO.4`QH_B%\J,X@CZO.4`QH_B
M%\J,X@#ZO.4`QH_B%\J,XOCYO.4`QH_B%\J,XO#YO.4`QH_B%\J,XNCYO.4`
MQH_B%\J,XN#YO.4`QH_B%\J,XMCYO.4`QH_B%\J,XM#YO.4`QH_B%\J,XLCY
MO.4`QH_B%\J,XL#YO.4`QH_B%\J,XKCYO.4`QH_B%\J,XK#YO.4`QH_B%\J,
MXJCYO.4`QH_B%\J,XJ#YO.4`QH_B%\J,XICYO.4`QH_B%\J,XI#YO.4`QH_B
M%\J,XHCYO.4`QH_B%\J,XH#YO.4`QH_B%\J,XGCYO.4`QH_B%\J,XG#YO.4`
MQH_B%\J,XFCYO.4`QH_B%\J,XF#YO.4`QH_B%\J,XECYO.4`QH_B%\J,XE#Y
MO.4`QH_B%\J,XDCYO.4`QH_B%\J,XD#YO.4`QH_B%\J,XCCYO.4`QH_B%\J,
MXC#YO.4`QH_B%\J,XBCYO.4`QH_B%\J,XB#YO.4`QH_B%\J,XACYO.4`QH_B
M%\J,XA#YO.4`QH_B%\J,X@CYO.4`QH_B%\J,X@#YO.4`QH_B%\J,XOCXO.4`
MQH_B%\J,XO#XO.4`QH_B%\J,XNCXO.4`QH_B%\J,XN#XO.4`QH_B%\J,XMCX
MO.4`QH_B%\J,XM#XO.4`QH_B%\J,XLCXO.4`QH_B%\J,XL#XO.4`QH_B%\J,
MXKCXO.4`QH_B%\J,XK#XO.4`QH_B%\J,XJCXO.4`QH_B%\J,XJ#XO.4`QH_B
M%\J,XICXO.4`QH_B%\J,XI#XO.4`QH_B%\J,XHCXO.4`QH_B%\J,XH#XO.4`
MQH_B%\J,XGCXO.4`QH_B%\J,XG#XO.4`QH_B%\J,XFCXO.4`QH_B%\J,XF#X
MO.4`QH_B%\J,XECXO.4`QH_B%\J,XE#XO.4P0"WI)-!-XN`QG^44`(WE$!"-
MY0P@C>40$(WB#""-XA0`C>(`,)/E'#"-Y0`PH..8___KN"&?Y;@!G^4"$*#A
M.@L`Z[`QG^4`4-/E``!5XZA!GQ4)```::O__ZZ`AG^4``%#C$`""Y5T```J,
M09_E0/__ZP``E.7=___K<5?`Y0``E.7:___K`#"@X0``E.7&(]/E`B""X\8C
MP^74___K%#"=Y04P@^('`7/CQB/0Y0$@@N/&(\#E1@``B@,!H.%6___K$!"=
MY3C!G^4P09_E`#"1Y10@G>4$P)SE`0!2XP`P@.4@,9_E","`Y00P@.48P9_E
M!#"@XP0PA.4$,$'"#,"`Y0(Q@\`,P(#""`"$Y0,``-H$X+'E`0!3X03@K.7[
M__\:#<&"X@`0H.,`$(WE`#"@X0P1@.<#((+BT!"?Y1``E.5W___K`%!0XA$`
M``H0`)3E'___Z[@`G^48$(WB;```ZP``4.,.```*$`"4Y0/__^ME___K<#"?
MY0`@D^4<,)WE`B`SX!<``!H%`*#A)-"-XC"`O>@0`)3E?___ZP!0H.'I___J
M#`"4Y0``4.,!```*:`8`Z^O__^I8`)_E&!"-XE,``.L``%#C#`"$Y>7__PKV
M___J0!"?Y4``G^4[___K`0"@XR3__^OM_O_KS((!`*P6`0`D%P$`&)`"`!20
M`@`HD`(`")`"`#!(`0`T2`$`2"$!`/1%`0"010$`Q(T"`&A'`0``L*#C`."@
MXP00G>0-(*#A!"`MY00`+>40P)_E!,`MY0P`G^4,,)_E_O[_ZUK__^O41`$`
MJ!<!`'1$`0`4,)_E%""?Y0,PC^`"()/G``!2XQ[_+P'Y_O_JS'0!`!`!```8
M`)_E&#"?Y0``4^$>_R\!$#"?Y0``4^,>_R\!$_\OX1"0`@`0D`(``````"0`
MG^4D$)_E`#!!X*,?H.%#$8'@P1"PX1[_+P$0,)_E``!3XQ[_+P$3_R_A$)`"
M`!"0`@``````$$`MZ1A`G^4`,-3E``!3XQ"`O1C@___K`3"@XP`PQ.40@+WH
M))`"`.;__^KP1RWI`)!0XBL```JX,)_E`("3Y0``6.,I```*`"#9Y0%PH.$]
M4%+B`5"@$P``4N,`4*`#``!5XQ$``!H`0)CE``!4XPP```H(8*#A!2"@X0D0
MH.$$`*#A$/__ZP``4.,"```:!3#4YST`4^,+```*!$"VY0``5./S__\:!`"@
MX?"'O>@)4*#A`3#UY0``4^,]`%,3^___&@E01>#F___J"&!&X`%0A>)&8:#A
M!4"$X`0`H.$`8(?E\(>]Z`E`H.'M___J"$"@X>O__^H0D`(`@#"?Y3!`+>D,
MT$WB>%"?Y0!`H.$`,)/E!#"-Y0`PH.,-$*#A!`"@X<#__^L``%#C#```"@`0
MG>4`()7E`3&"X`3`D^4``%SC`<&"Y_/__PH$,(/B!""3Y0``4N,$((/D^___
M&NW__^H8,)_E`""3Y00PG>4"(#/@`0``&@S0C>(P@+WH3?[_ZYR"`0`0D`(`
M\$\MZ0%`H.$`,-'E["&?Y0S03>(]`%/C`4"!`@!0H.$$`*#A`""2Y00@C>4`
M(*#C=_[_ZPT0H.$`8*#A!0"@X9;__^L`D%#B/@``"G#^_^L&`%#A-0``*@!P
MG>6@@9_E!W&@X0``U>4](%#B`2"@$P``4.,`(*`#``!2XP4```H%(*#A`3#R
MY0``4^,]`%,3^___&@4@0N`"`(;B`@"`X`!@F.5(_O_K``!0XP<`AN=,```*
M`""8Y0`0G>4%`*#A`3#0Y`$1DN<]`%/C``!3$P`PP>4&```*`2"!X@$PT.0"
M$*#A``!3XST`4Q,!,,+D^?__&@$@H.$],*#C`##!Y0$PU.0``%/C`3#BY?O_
M_QH``*#CY#"?Y0`@D^4$,)WE`B`SX#0``!H,T(WB\(^]Z`&02>(!,-3D``!3
MXP$PZ>7[__\:\?__ZK2`G^4`H)CE`#":Y0``4^,D```*"C"@X00@L^4)$*#A
M``!2XP&0B>+Z__\:`Q"!X@$1H.&$,)_E`""3Y0``4N,/```:`2"@XP$`H.$`
M((/E"_[_ZP"P4.(0```*"7&@X0H0H.$'(*#AP/W_ZP"PB.4!,(GB`""@XP,A
MB^<`D(WEI?__Z@H`H.'?_?_K``!0XP"PH.$)<:`1``"(Y?/__QH``.#CR/__
MZ@.0H.$($*#CW___ZLO]_^N@@@$`$)`"`"B0`@!0,9_E\$$MZ0!`4.)XT$WB
M`#"3Y70PC>4`,*#C`@``"@`PU.4``%/C!@``&B0QG^4`()/E=#"=Y0(@,^!$
M```:>-"-XO"!O>C6_?_K`%!0XO7__PH`<9_E!0"@X2C^_^L``%#C)@``"A,P
MT.43@(#B+@!3XR<```H3,-#E+@!3XRH```H$`*#AWOW_ZP!@H.$(`*#AV_W_
MZP``AN`"`(#BQOW_ZP<PH.$`(.#C`1"@XQ`!C>@`8*#AX?W_ZP80H.$(((WB
M`P"@XQ;^_^L!`'#C!@"@X0,```H8,)WE#SH#X@$)4^,8```*D_W_ZP8`H.%P
M_?_K!0"@X0'^_^L``%#CV/__&@4`H.$5_O_K!`"@X73]_^O$___J`3#8Y0``
M4^/,__\*$S#0Y2X`4^/4__\:`3#8Y2X`4^/1__\:`C#8Y0``4^/#__\*S?__
MZJO__^OE___J<OW_ZZ2"`0`T10$`$$`MZ7#03>)T,)_E`!"@X0!`H.$-(*#A
M`P"@XP`PD^5L,(WE`#"@X_+]_^L``%#C``"@$P0``!H0,)WE#SH#X@H*4^,!
M"5,3!@``"C`PG^4`()/E;#"=Y0(@,^`'```:<-"-XA"`O>@$`*#A`A"@X[_]
M_^L0#V_AH`*@X?+__^I/_?_KJ((!`/!`+>D!VDWB#-!-XMS`G^4!.HWBV""?
MY0!@H.$!4*#AT`"?Y000C>($,(/B`,"<Y0#`@^4`P*#C4?W_ZP#`4.(A``#:
M"#"-X@%`3.($X(/@I""?Y00P7N4`<)+E``!3XQ<``!H``%3C&0``"@0@H.$O
M$*#C!`"-XIC]_^L``%#C$P``"@<`H.&^_?_K!#"@X00@C>(&$*#AHOW_ZP$Z
MC>)(()_E!#"#X@`0DN4`()/E`1`RX`P``!H!VHWB#-"-XO"`O>@,0*#AY___
MZB@PG^4`<)/E!P"@X:K]_^L%(*#A!A"@X2/]_^OK___J$OW_ZZR"`0#_#P``
M/$4!`!20`@`<,)_E$$`MZ0``D^6=_?_K$$"]Z`PPG^4,()_E#!"?Y5/]_^H4
MD`(`T((!``@5`0!,10$`$$`MZ0C03>(T0)_E``"4Y8_]_^OL___K``"4Y8S]
M_^L@,)_E`""@XP0@C>48$)_E&""?Y0`PC>58_?_K"-"-XA"`O>@4D`(`+$@!
M`&A%`0"0+P$`,$`MZ0+:3>(<T$WBJ""?Y0(ZC>(4,(/B`""2Y0`@@^4`(*#C
M%?W_ZY`PG^60()_E`1"@XPD`C>B(,)_E#`"-XB/]_^L!&HWB#`"-XA`0@>(!
M*J#CZ/S_ZP!`4.(`4*"S"0``N@$`A.+X_/_K`%!0X@4```H!&HWB$!"!X@0@
MH.&V_/_K`#"@XP0PQ><".HWB)""?Y10P@^(`$)+E`""3Y0$0,N`#```:!0"@
MX0+:C>(<T(WB,("]Z+W\_^NP@@$`C$4!``$0``"`10$`R___ZO!/+>E"W4WB
M!-!-XO0AG^5!/8WB`%"@X0%@H.'H`9_E$!"-XCPP@^(`()+E`""#Y0`@H.,&
M_O_K+Q"@XP!`H.$%`*#AY?S_ZP``4.,-```*N`&?Y040H.%5_O_K!0"@X4$]
MC>*<(9_E/#"#X@`0DN4`()/E`1`RX&$``!I"W8WB!-"-XO"/O>@%`*#AS?S_
MZWP1G^4`@*#A!@"@X?_\_^L`H%#BZ?__"@`PVN5DD9_E7'&?Y0``4^-\8(WB
M.0``"@``5.,$```*"A"@X00`H.%9_/_K``!0XRD```H*`*#AN/S_ZP$00.(!
M,(K@`2#:YP#@H.$O`%+C"@``&@(`0.(``(K@`P!`X`,00>`#(*#A`+"@XP'@
M@^``L,/F`<!RY2\`7./Z__\*`3"(X@[@@^`!"E[CQ?__JMPPG^4!*J#C`1"@
MXP0PC>4&`*#A"3"@X0A0C>4`H(WEJ?S_ZQ`@C>(&$*#A`P"@X][\_^L``%#C
M`P``&B`PG>4/.@/B`@E3XQ0```H'$*#A``"@X\/\_^L``%#C`*"@X:S__PH`
M,-KE``!3X\7__QH``%3C`@``"@`PU.4N`%/C`@``"ER@G^4!X*#CU___Z@$P
MU.4``%/CZ___"OC__^H!$*#C!@"@X:O\_^L``%#CY?__&@80H.$8`)_E[OW_
MZP8`H.$U_/_KEO__ZC;\_^NT@@$`D$4!`)Q%`0"L10$`L$4!`+A%`0``10$`
M`##0Y0``4^,>_R\!`2"`XB\`4^,"`*`!`3#2Y```4^/Z__\:'O\OX1!`+>D`
M0%#B+```"@`PU.4``%/C*0``"E?\_^L!`$#B`#"$X`,`5.$#(*`Q`P``.B4`
M`.H$`%+A`C"@X2(```H",*#A`1!2Y"\`4>/X__\*`P!4X1P``"H!,$/B`P!4
MX1L```H`(-/E+P!2X_G__QH!,$/B`P``Z@`0T^4!,$/B+P!1XP(``!H#`%3A
M`R"@X?C__SH$($+@`C""X@$*4^,1``"*`2""X@00H.$!.J#C/`"?Y?'[_^LT
M`)_E$("]Z!!`O>@L`)_E[_O_Z@,`5.'F__\:`##3Y2\`4^/W__\*$$"]Z!``
MG^7G^__J``"@XQ"`O>@\D`(``$4!`+A%`0`$X"WE--!-XD#AG^5`,9_E","-
MX@`PD^4L,(WE`#"@XP\`ON@/`*SH#P"^Z`#@GN4/`*SH'`&?Y;#@S.%E_?_K
M%`&?Y6/]_^L0`9_E8?W_ZPP!G^5?_?_K"`&?Y5W]_^L$`9_E6_W_ZP`!G^59
M_?_K_`"?Y5?]_^OX`)_E5?W_Z_0`G^53_?_K\`"?Y5']_^L$$(WBZ`"?Y1K]
M_^L`$%#B`0``"LP`G^5N_?_K!!"-XM``G^43_?_K`!!0X@$```K$`)_E9_W_
MZP00C>*\`)_E#/W_ZP`04.(+```*C`"?Y6#]_^NH$)_E>`"?Y5W]_^M<,)_E
M`""3Y2PPG>4"(#/@$0``&C30C>($\)WD!!"-XH``G^7[_/_K`!!0X@(```I,
M`)_E3_W_Z^W__^IH$)_E"B"@XQD`C>(:_/_K``!0X^?__QHC$(WB]/__ZI'[
M_^O<@@$`N((!`+Q%`0#(10$`T$4!`-Q%`0#D10$`]$4!`)!%`0``1@$`#$8!
M`!A&`0"<10$`)$8!`#A&`0`$10$`3$8!`'Q&`0!<1@$`<$8!`!!`+>D(T$WB
M:$"?Y6@PG^4``)3E`#"3Y00PC>4`,*#C`0!PXP8```I,,)_E`""3Y00PG>4"
M(#/@#0``&@C0C>(0@+WH-`"?Y0T0H.'%_/_K``!0XP0```H``-#E,`!0XP``
M4!,!`*`3``"@`P``A.7L___J7_O_ZPB0`@"\@@$``$8!`!!`+>DY^__K,OO_
MZP``4.,``)`5$("]Z'!`+>D8T$WBL#"?Y0!0H.$0$(WBJ`"?Y0`PD^44,(WE
M`#"@XZC\_^L%$*#A`$!0X@(```H`,-3E``!3XP@``!I\`)_E^/S_ZW`PG^4`
M()/E%#"=Y0(@,^`7```:&-"-XG"`O>@/^__K``!0X_7__QH%`*#A<?O_ZP!@
MH.$$`*#A;OO_ZP``AN`"`(#B6?O_ZS`PG^4!$*#C"$"-Y00PC>4`(.#C(#"?
MY0!0C>4`0*#A<?O_ZP00H.'@___J)OO_Z\""`0"`1@$`K$4!`+!%`0!P-I_E
M\$\MZ0!PH.$"V4WB!P"3Z/S03>*$P(WB#$"#X@<`C.@DP(/B#P"TZ`)9C>)$
M9I_EG."-X@!@EN7T8(7E`&"@XP\`KNCT4(7B`P"4Z)!0C>(#`([H!P"<Z`<`
MA>@8$(WB%`:?Y6/\_^L`0%#B`@``"@`PU.4``%/C``$`&J3__^L`4%#BV0``
M"@4`H.$V^__K@`"@X0$`@.(A^__K`"#5Y0``4N,`8*#A"P``"LR%G^4&0*#A
M!`"@X0`@C>4(,*#A`"#@XP$0H.,V^__K`2#UY0)`A.(``%+C]?__&J`%G^6@
M4(WB`@``Z@0`E>0``%#C#0``"A@0C>(^_/_K`$!0XOC__PH`,-3E``!3X_7_
M_PIK_?_K``!0X_+__PH$`*#AU?K_ZP!`4.(4```:`%"@XX20C>+X,(WB!3&#
MX'1`$^4``%3C#```"@&`A>((@8G@`##4Y0``4^,'```*!`"@X5?]_^L!4(7B
M``!0XSH``!H$0)CD``!4X_3__QH`0*#C!`"@X?CZ_^OXE)_E`*"@X08`H.'T
M^O_K``"*X`&K@.($H(KB"@"@X=WZ_^O8-)_E`"#@XP$0H.,(,(WE#&"-Y<@T
MG^4`0(WE!)"-Y0"`H.'T^O_K"`"@X0<=H./Z^O_K`0!PXP,``!KK^O_K`#"0
MY1$`4^.7```:&""-X@@0H.$#`*#C+/O_ZP!04.(7```*?"2?Y0"`C>4!$*#C
M``"2Y0`PE^5L))_E^?K_ZP!@H.,".8WB/"2?Y?0P@^(`$)+E`""3Y0$0,N`(
M`0`:!@"@X0+9C>+\T(WB\(^]Z`0`H.&%^O_K`$!0XK'__PK#___J*#"=Y0\Z
M`^(!"5/CX___&C!`G>5>^O_K``!4X=___QHH,)WE@SN@X:,[H.$'#5/CVO__
M&@H`H.&=^O_K&!"-X@!@H.'@`Y_ESOO_ZP``4.-Y```*`$"7Y6OZ_^L`$*#A
M!`"@X;+]_^L`H%#B<@``"@H`H.&@^O_K`P!0XP!`H.$+``":!`!`XJ`3G^4`
M`(K@-OK_ZP``4.,%```:!`!4XZ@```H$0(K@!3!4Y2\`4^.D```*V?[_ZP`0
M4.(#```:"@"@X7?Z_^L`0%#B7```&EP3G^5<`Y_E`OS_ZX#Z_^M4<Y_E5#.?
MY0`@X.,!$*#C\(#-X0QPC>5$HY_E"`"-Y08`H.&+^O_K#@``ZH;Z_^L`,)#E
M$0!3XQ```!IP^O_K`5"%X@0@H.$*,*#A`1"@XPQ0C>40<(WE\(#-X0@`C>4&
M`*#A>_K_ZP<=H.,&`*#A@?K_ZP$`<.,`0*#AZO__"@@`H.$0^O_K!A"@X9@"
MG^7<^__K!@"@X<_^_^N/___J!8"@X9!@C>+X,(WB"#&#X&@`$^4``%#C(0``
M"@%`B.($48;@&!"-XG;[_^L$@*#A`#!0X@(```H`,-/E``!3XP0``!H$`)7D
M``!0XQ0```H!0(3B\O__Z@OZ_^L`4%#BZ/__"@O__^HT(I_E!#"-Y0"`C>4!
M$*#C``"2Y0`PE^5`(I_E9OK_ZP!@H.-K___JJ?[_ZP0`H.'[^?_K`&"@X6;_
M_^H-`*#C(?K_ZQA2G^53(*#C`&"@X?_^_^H`H)?EBO__Z@)0H.,`,.#C$2#@
MXP!0C>4*^O_K]!"-X@8@H.,$`*#AQ_G_Z_0PW>4``%/C`@``&O4PW>5#`%/C
M/P``"@`PH.,`(*#C`#"-Y00`H.$`,*#C^OG_Z^,$`.L`4*#A`@``ZO00C>(%
M`*#A`04`ZP(IH./T$(WB!`"@X;'Y_^L`(%#B]O__R@0`H.%;^O_K!1"@X;0`
MC>)&!0#KR*"-XO@PC>(DL9_E"E"@X45`0^(Q<$/B`1#TY04`H.$+,*#A`!"-
MY0`@X.,!$*#C"?K_ZP0`5^$"4(7B]?__&A@QG^4``*#C##"-Y?``S>4<,9_E
M`"#@XP$0H.,&`*#A``>-Z/SY_^N%___J!$"7Y0``5.-7__\*!`"@X>?Y_^L#
M`%#C4___F@0`0.+D$)_E``"$X'[Y_^L``%#C!*"@`4S__^KV,-WE00!3X[S_
M_QKW,-WE0P!3X[G__QKX,-WE2`!3X[;__QKY,-WE10!3X[/__QH`,.#C.2#@
MXP0`H.$`4(WEK_G_Z_00C>($`*#A*2"@XVSY_^M@,)_E]""-X@@@C>4,,(WE
M`"#@XV`PG^4!$*#C!@"@X?"`S>'.^?_K5___ZH3Y_^L`@P$`Q((!`)!%`0"8
M1@$`!$4!`+A%`0"L1@$`H$8!`""0`@#P1@$`1$<!`$Q'`0!\1@$``$8!`"Q(
M`0!L1P$`?$<!`+1&`0"01@$`7$<!`%1'`0#P3RWI#-!-XBQ3G^4L,Y_E``"5
MY0`PD^4$,(WE`#"@X_GY_^L`0*#A``"5Y?;Y_^MH(-3E#1"@X0`PH.$``Y_E
M:2##Y;GZ_^L``%#C`@``"@`PT.4Q`%/CGP``"G']_^L``)7EZ/G_Z]@2G^4+
M,*#C`2"@XW[Y_^L``%#C+P``"L1RG^40$)#E`*"5Y00@E^48D)'E`0!2XRH`
M`-H`0*#C"0``ZA`0DN4(`*#A&?G_ZP0@E^4``%#C;P``&@)`A.("`%3A!D"@
MX6L``*H*`*#AS?G_ZP`PH.,$(*#A"1"@X:CY_^L`L%#B80``"@`@F^4($)?E
M`6"$X@@PDN4&@9'G_S3#X]\XP^/[/,/C_S##XP$+4^,`H)7EX?__"@H`H.&Y
M^?_K`!";Y0(PH.,`(*#C-_G_ZP"@E>4`$*#AV?__Z@"@E>4`<I_E"@"@X:[Y
M_^OX$9_E`S"@XP$@H.-$^?_K`$!0X@H```H``)7EIOG_ZQ`PE.78(9_E`!"3
MY1[Y_^L0,)3E`#"3Y0@PD^4!!1/C7```&@``E>6;^?_KM!&?Y0,PH.,!(*#C
M,?G_ZP!`4.(*```*H`&?Y0T0H.%;^O_K`&!0X@``E>5'```*COG_ZQ`PE.4&
M(*#A`!"3Y0;Y_^L``)7EB/G_ZP!`H.$``)7EA?G_ZV01G^4!(*#C,?G_ZUPA
MG^4`$*#A!`"@X?KX_^L``)7E?/G_ZP`PH.,-$*#A:3#`Y3P!G^5`^O_K``!0
MXP!`H.$,`(?E'P``"@<=H.,$`*#A+OG_ZP$P@.(1`%#C`0!3$S(``(K@,)_E
M`""3Y00PG>4"(#/@+```&@S0C>+PC[WH!""7Y0"@E>4!$$+B!`!1X:___QH!
M`%+CK?__V@%`H.,*`*#A6_G_ZPD0H.&N^/_K!#"7Y0%`A.($`%/A`*"5Y?;_
M_\JB___J"`"7Y9O]_^L``%#C`$"@X0P`A^79__\:D`"?Y0/Y_^L!,-#E``!3
MXUW__PI;___J1OG_ZQ`@E.4(,)?E``"2Y0`0D^5?^__KM?__Z@``E>4^^?_K
M$#"4Y0`0D^4%^?_KG/__ZJ;X_^L($)?E`#"@X00@H.$`$)'E-`"?Y>OX_^L4
MD`(`R((!`.1%`0"01P$`*)`"`)A'`0"<1P$`I$<!`)Q%`0"H1P$`P$<!`)!%
M`0#(1P$`[$<!`'!`+>D`4*#A:?S_ZP`PT.4`0*#A``!3XP4```H!((#B+P!3
MXP)`H`$!,-+D``!3X_K__QH&_?_K``!5XP``4!-P@+T(`##5Y0``4^-P@+T(
M'!"?Y00`H.$$(*#C_OC_ZP``4.-P@+T8!0"@X7!`O>BL^O_JK$8!``````#(
M/9_E\$\MZ:7?3>)`$(#B@%"`X@@@C>(`0*#C`#"3Y8PRC>4`,*#C!,`1Y0C@
M$>4($('B+#2@X?\\`^(L/(/A#&2@X0P\@^'_R`;B##"#X04`4>$^S[_F!$""
MY0Q`@N4(,(+E`,""Y1`@@N+M__\:`NR-X@T0H.$`0*#C`<"@X0A@L>5(4)SE
M<#"<Y1B`G.5T()SE3'"<Y04P(^`<4)SE"#`CX`3`D>4'("+@!C`CX`4@(N`,
M("+@H\^@X8+`C.&#,(SA#@!1X81`@>6`,('EZ?__&@B@D.4,X)#E`)"0Y2K!
MH.$.SXSA$("0Y0I?C.$$()#E&,"0Y=0\G^4($)WE#&`HX*GMH.$@P)#E`Q"1
MX(+BCN$,0)'@B<*.X03`G.`80)#E"F`&X`1@)N`0$)WE*4&@X07@*.`"3X3A
M&""0Y0;`G.`)X`[@`Q"1X`E/A.$(X"[@`A"1X!@@G>7L;:#A#A"1X`3@)>`&
M$)'@#.`.X`,@DN!LP:#A!>`NX"!PG>4(()+@X6V@X0X@DN`,X"3@!B"2X`'@
M#N`#<)?@81&@X03@+N`HL)WE!7"7X`Y0E^#B;:#A`>`LX`90E>`"X`[@`[";
MX&(AH.$,X"[@,'"=Y01`F^#E;:#A#D"4X`+@(>`&0)3@!>`.X`-PE^!E4:#A
M#,"7X`'@+N`X<)WEY&V@X0[@G.`%P"+@!N">X`3`#.`#<)?@9$&@X0$0E^`"
MP"S@0'"=Y>YMH.$,P)'@!!`EX`;`G.`.$`'@`W"7X&[AH.$"()?@!1`AX$AP
MG>7L;:#A`1"2X`X@).`&$)'@#"`"X`-PE^!LP:#A!"`BX`50E^!0<)WEX6V@
MX0)0E>`,("[@!E"5X`$@`N`#<)?@81&@X0X@(N`$0)?@6'"=Y>5MH.$"0)3@
M`2`LX`9`E.`%(`+@`W"7X&51H.$,("+@#N"7X&!PG>7D;:#A`N">X`4@(>`&
MX)[@!"`"X`-PE^!D0:#A`2`BX`S`E^!H<)WE[FV@X0+`G.`$("7@!L"<X`X@
M`N`#<)?@;N&@X04@(N`!$)?@<'"=Y>QMH.$"$)'@#B`DX`80D>`,(`+@`W"7
MX&S!H.$$("+@!5"7X'APG>7A;:#A`E"5X`P@+N`&4)7@`2`"X`-PE^!A$:#A
M#B`BX`1`E^"`<)WEY6V@X0)`E.`!("S@!D"4X`4@`N`#<)?@95&@X0[@E^`,
M("+@B'"=Y>1MH.$"()[@!>`AX`8@DN`$X`[@`W"7X&1!H.$,P)?@`>`NX)!P
MG>7B;:#A#N"<X`3`)>`&X)[@`L`,X`-PE^!B(:#A!<`LX`$0E^"8<)WE[FV@
MX0P0D>`"P"3@!A"1X`[`#.`#<)?@H+"=Y03`+.`%4)?@X6V@X0Q0E>!NP2+@
M!E"5X`'`#.`#,)O@!&"3X`+`+."P.9_EJ$"=Y6$1H.$,P);@Y6V@X0;`G.!N
M82'@`T"4X`5@)N`"()3@L$"=Y08@DN#L?:#A!W"2X&[AH.%E(2'@`T"4X`[@
ME.`,0"+@N""=Y6S!H.$$X)[@YTV@X03@GN!E02S@`R"2X`=`).`!()+@P!"=
MY00@DN#N3:#A!&"2X&51H.%G(2S@`Q"1X`50D>`.$"+@R""=Y6[AH.'F3:#A
M`1"5X`00D>!G02[@`R"2X`9`).`,()+@T,"=Y00@DN#A3:#A!""2X&=QH.%F
M02[@`\"<X`=PG.`!0"3@V,"=Y010E^!A$:#AXGV@X0=0E>!F02'@`\"<X.!P
MG>4"0"3@#N"<X`3@GN#ES:#A#.">X&9!H.$#P)?@8F$AX`3`G.`%0";@Z&"=
MY651H.'N?:#A!,"<X`?`G.!B027@`V"6X`Y`).`!$);@\&"=Y000D>#L3:#A
M!!"1X&(AH.%N027@`V"6X`Q`).`"();@^&"=Y6S!H.$$()+@X4V@X00@DN!N
M<2S@`T"6X`5`E.`!4"?@`'&=Y05`E.#B7:#A!4"4X&%A+.`#<)?@;N&@X0)@
M)N`(49WE#N"7X&(AH.$&X)[@Y&V@X0;@GN!A82+@`U"5X`1@)N`,P)7@$%&=
MY0;`G.#N;:#A!L"<X&$1H.%D82+@`U"5X`Y@)N`8<9WE`1"5X&[AH.'L7:#A
M!A"1X`40D>!D82[@`W"7X`Q@)N`@49WE`B"7X`8@DN#A;:#A!B"2X&1!H.%L
M82[@`U"5X`%@)N`H<9WE!$"5X&$1H.'B7:#A!D"4X`5`E.!L82'@`W"7X`)@
M)N`P49WE#N"7X`;@GN#D;:#A!N">X&S!H.%B82'@`U"5X`1@)N`X<9WE#,"5
MX&1!H.'N7:#A!L"<X`7`G.!B823@`W"7X$!1G>4.8";@`1"7X&[AH.$&$)'@
M[&V@X080D>!B(:#A#F`DX`,PE>!(<9WE#&`FX`(@D^!LP:#AU#:?Y0Q0CN$&
M()+@X6V@X08@DN`,L`[@`V"7X`%0!>`+4(7A81&@X5!QG>4$0);@!4"4X`%@
MC.'B7:#A!4"4X`)@!N`!4`S@`W"7X&(AH.$.<)?@!6"&X5A1G>4"L('AY.V@
MX0=@EN`.8);@!+`+X`)P`>`#X)7@9$&@X0=PB^$,X)[@8+&=Y03`@N$.X)?@
MYGV@X0?@GN`$4`+@`[";X`;`#.!H<9WE9F&@X0$0F^`%P(SA`<"<X`90A.'N
M':#A#K`%X`'`G.`&4`3@`Q"7X&[AH.$%4(OA`A"1X`$0E>`.((;A[%V@X040
MD>`,(`+@#E`&X`4@@N%PL9WE>%&=Y6S!H.$$4(WE`[";X`Q0CN$$0)O@`;`%
MX`10G>4$0)+@X2V@X0)`E.!A$:#A#'`.X`,@E>`'<(OA!B"2X("QG>4!8(SA
M!&`&X`%0#.`"()?@Y'V@X0<@DN`%4(;A`[";X(AAG>4.X)O@!&"-Y0Y0E>#B
M[:#A9$&@X0Y0E>`$X)WE!'"!X0*P!^`$8`'@`^">X&(AH.$&8(OA#,">X)#A
MG>4"L(3A#,"6X.5MH.$&P)S@!;`+X`)@!.`#X)[@!K"+X0$0GN#L;:#A`1";
MX&51H.$&$)'@F&&=Y05P@N$%L`+@#.`'X`-PEN`$0)?@"^".X>%MH.$$X)[@
M!N">X&S!H.&@89WE#$"@X0RPA>$$<`7@`<`+X`-@EN!A$:#A`B"6X`?`C.&H
M<9WE`6"$X0+`G.#N+:#A`L"<X`&P!.`#<)?@#F`&X&XAH.$%4)?@"^"&X;!Q
MG>4"8('A!>">X.Q=H.$%X)[@`K`!X`Q@!N`#<)?@;%&@X01PE^`+P(;AN+&=
MY05`@N'N;:#A!\"<X`;`G.`%<`+@`V";X`Y`!.`'0(3A;N&@X<!QG>4!$);@
M`1"4X`Y@A>'L3:#A!!"1X`Q@!N`.L`7@`W"7X&Q!H.$+L(;A`B"7X,AQG>4$
M8([AX<V@X0(@F^`,()+@!+`.X`-PE^`!8`;@8<&@X0M@AN$%4)?@T+&=Y0P0
MA.$%4);@XFV@X090E>`,<`3@`V";X`(0`>#8L9WE8B&@X0[@EN`'$('A#A"1
MX`)PC.'E[:#A#A"1X`5P!^`"8`S@`^";X&51H.$&8(?A!.">X.!QG>4%0(+A
M#N"6X.%MH.$&X)[@`4`$X`5@`N`#,)?@!D"$X>BQG>4,P)/@5#.?Y>YMH.$,
MP)3@!L"<X&%!)>`#L)O@`K";X`Y`).#P(9WE;N&@X>QMH.$$0)O@!D"4X&%A
M+N`#()+@#&`FX`4@DN#X49WE!B"2X.1MH.$&<)+@81&@X6PA+N`#4)7@`1"5
MX`10(N``(IWE9$&@X040D>#G7:#A!1"1X&Q1).`#()+@!U`EX`X@DN`(XIWE
M!2"2X.%=H.$%L)+@;,&@X6<A).`#X)[@#,">X`'@(N`0(IWE81&@X0[`G.#K
M[:#A#N"<X&=1(>`#P)+@"U`EX`3`G.`80IWE!<"<X.Y=H.$%P)S@9R&@X6M1
M(>`#0)3@#E`EX`)`E.`@(IWE;N&@X>QMH.$%0)3@!D"4X&M1+N`#()+@#%`E
MX`$@DN`H$IWE!2"2X.1MH.$&<)+@:U&@X6PA+N`#$)'@!1"1X`10(N`P(IWE
M9$&@X040D>#G7:#A!1"1X&Q1).`#()+@!U`EX`X@DN`XXIWE!2"2X.%MH.$&
ML)+@;,&@X6<A).`#X)[@#,">X`'@(N!`(IWE81&@X0[`G.#K[:#A#L"<X&?A
M(>`#()+@!$"2X`L@+N!(XIWE`B"4X.Q-H.$$0)+@9V&@X6LA(>`#X)[@!F">
MX`S@(N!0(IWE;,&@X0Y@EN#D[:#A#N"6X&M1+.`#()+@`1"2X`0@)>!84IWE
M[GV@X0(0D>`'$)'@9&$LX&LAH.$#4)7@#F`FX`)0E>!@(IWEX7V@X090E>!N
M8:#A!U"5X&3A)N`#()+@`>`NX`P@DN!HPIWE#B"2X.7MH.$.()+@9$&@X6'A
M)N`#P)S@!>`NX`1`G.!PPIWE95&@X>)]H.$.0)3@!T"4X`;@H.%A<27@`V"<
MX`)P)^!XPIWE#F"6X`=@EN!BX:#AY"V@X0)@EN!A$:#A`R"<X`YP)>`!()+@
M!'`GX(`2G>4'()+@YLV@X0S`DN!D0:#A`S"1X`0@+N`),)/@!B`BX`4PD^`"
M,)/@["V@X0(PD^`8()#E9F&@X0K`G.`(8);@`D"4X"`@D.4`,(#E1#"?Y0`0
MH.,"X)[@","`Y1!@@.480(#E(."`Y000@.4,$(#E%!"`Y1P0@.4D$(#E`""3
MY8PRG>4"(#/@`0``&J7?C>+PC[WH__3_ZS"#`0"9>8):H>O9;MR\&X_6P6+*
M\$<MZ8``H.,>]?_K4%"/XM!`Q>%0<(_BT&#'X5"0C^+0@,GA`""@X_A`P.%(
M4(_BT$#%X?!AP.%$<(_BT&#'X?A!P.$`0*#C`%"@X_"`P.'P8L#A>""`Y?A"
MP.'P0\#A\(>]Z(FKS>\`````_MRZF``````!(T5G`````'94,A``````\.'2
MPP````#X3RWI`I"@X=@BP.$`4*#A`'"@XXD!H.$"8(#@!P!3X08`4@$!0*#A
M,""5Y300E>4)H*#AR;^@X0$``)H!()+B!Q"AX*H^H.%X`)7EBS&#X0(PD^"K
M+J#A`2"BX```4.,X@(7B^&+%X3`PA>4T((7E'P``&C\`6>,N``#:0)!)XBEC
MH.$!<(;B!W.$X$#@A.((,*#A`,"4Y00`E.4($)3E#""4Y1!`A.(.`%3A`,"#
MY00`@^4($(/E#""#Y1`P@^+S__\:!0"@X3#\_^L'`%3A[?__&@9M9N`&DXG@
M!Q"@X0@`H.$)(*#AA_3_ZWB0A>7XC[WH0&!@X@8`6>$)8*"Q``"(X`8@H.$$
M$*#A?O3_ZW@PE>4#,(;@0`!3XW@PA>7XC[T8!0"@X0:02>`&0(3@%OS_Z\[_
M_^H$<*#AYO__ZO!!+>DX<('B`4"@X2@0D>4P8)3E?\#@XZ$QH.$_,`/B`2"#
MXC@`4N,`4*#A,8^_YC9OO^8"`(?@`\#'YSP``-I`(&+B`!"@X\CT_^L$`*#A
M_OO_ZP<`H.$X(*#C`!"@X\+T_^L$`*#A<&"$Y72`A.7V^__K`S#4Y00`H.$`
M,,7ELC#4X0$PQ>4`,)3E(S2@X0(PQ>4`,)3E`S#%Y0LPU.4$,,7ENC#4X04P
MQ>4(,)3E(S2@X08PQ>4(,)3E!S#%Y1,PU.4(,,7ELC'4X0DPQ>40,)3E(S2@
MX0HPQ>40,)3E"S#%Y1LPU.4,,,7ENC'4X0TPQ>48,)3E(S2@X0XPQ>48,)3E
M#S#%Y2,PU.40,,7ELC+4X1$PQ>4@,)3E(S2@X1(PQ>4@,)3E$S#%Y?!!O>@?
M]/_J."!BX@`0H..+]/_KQ___ZO!'+>D`<*#A2&"?Y4A0G^4&8(_@!5"/X`5@
M1N`!@*#A`I"@X??S_^M&8;#A\(>]"`!`H.,$,)7D`4"$X@D@H.$($*#A!P"@
MX3/_+^$$`%;A]___&O"'O>@P20$`*$D!`![_+^$(,)_E`S"/X``PD^4<]/_J
M($L!``A`+>D(@+WH`0`"`"]T;7``````+@```%!!4E]435!$25(``%1%35!$
M25(`5$U0`%5315(`````55-%4DY!344`````+BX``"5S+R5S````+W!R;V,O
M<V5L9B]E>&4``$1Y;F%,;V%D97(Z.F)O;W1?1'EN84QO861E<@!);G1E<FYA
M;',Z.E!!4CHZ0D]/5``````O<')O8R\E:2\E<P!E>&4`4$%27U1%35``````
M4$%27U!23T=.04U%`````#H````E<R5S)7,``"\```!015),-4Q)0@````!0
M15),3$E"`%!%4DPU3U!4`````%!%4DQ)3P``4$%27TE.251)04Q)6D5$`%!!
M4E]34$%73D5$`%!!4E]#3$5!3@```%!!4E]$14)51P```%!!4E]#04-(10``
M`%!!4E]'3$]"04Q?1$5"54<`````4$%27T=,3T)!3%]435!$25(```!005)?
M1TQ/0D%,7U1%35``4$%27T=,3T)!3%]#3$5!3@````!005)?0TQ%04X]```Q
M````3$1?3$E"4D%265]0051(`%-94U1%30``)3`R>``````E<R5S)7,E<P``
M``!P87(M`````"5S.B!C<F5A=&EO;B!O9B!P<FEV871E('-U8F1I<F5C=&]R
M>2`E<R!F86EL960@*&5R<FYO/25I*0H``"5S.B!P<FEV871E('-U8F1I<F5C
M=&]R>2`E<R!I<R!U;G-A9F4@*'!L96%S92!R96UO=F4@:70@86YD(')E=')Y
M('EO=7(@;W!E<F%T:6]N*0H``%!!5$@`````<&%R;``````N<&%R`````"5S
M)7-C86-H92TE<R5S```E<R5S=&5M<"TE=25S````)7,E<W1E;7`M)74M)74E
M<P````!!4D=6`````!@```!P97)L`````#````!005(Z.E!A8VME<CHZ5D52
M4TE/3@`````Q+C`T.0```%5N86)L92!T;R!C<F5A=&4@8V%C:&4@9&ER96-T
M;W)Y`````"5S.B!C<F5A=&EO;B!O9B!P<FEV871E(&-A8VAE('-U8F1I<F5C
M=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H`````+64``"TM``!E=F%L("=E
M>&5C("]U<W(O8FEN+W!E<FP@("U3("0P("1[,2LB)$`B?2<*:68@,#L@(R!N
M;W0@<G5N;FEN9R!U;F1E<B!S;VUE('-H96QL"G!A8VMA9V4@7U]P87)?<&P[
M"FUY("@D4$%27TU!1TE#+"`D<&%R7W1E;7`L("1P<F]G;F%M92P@0'1M<&9I
M;&4I.PI%3D0@>R!I9B`H)$5.5GM005)?0TQ%04Y]*2!["G)E<75I<F4@1FEL
M93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*<F5Q=6ER92!&:6QE
M.CI3<&5C.PIM>2`D=&]P9&ER(#T@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H
M)'!A<E]T96UP*3L*;W5T<RAQ<7M296UO=FEN9R!F:6QE<R!I;B`B)'!A<E]T
M96UP(GTI.PI&:6QE.CI&:6YD.CIF:6YD9&5P=&@H<W5B('L@*"`M9"`I(#\@
M<FUD:7(@.B!U;FQI;FL@?2P@)'!A<E]T96UP*3L*<FUD:7(@)'!A<E]T96UP
M.PII9B`H+60@)'!A<E]T96UP("8F("1>3R!N92`G35-7:6XS,B<I('L*;7D@
M)'1M<"`](&YE=R!&:6QE.CI496UP*`I414U03$%412`]/B`G=&UP6%A86%@G
M+`I$25(@/3X@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'1O<&1I<BDL"E-5
M1D9)6"`]/B`G+F-M9"<L"E5.3$E.2R`]/B`P+`HI.PIP<FEN="`D=&UP("(C
M(2]B:6XO<V@*>#TQ.R!W:&EL92!;(%PD>"`M;'0@,3`@73L@9&\*<FT@+7)F
M("<D<&%R7W1E;7`G"FEF(%L@7"$@+60@)R1P87)?=&5M<"<@73L@=&AE;@IB
M<F5A:PIF:0IS;&5E<"`Q"G@]8&5X<'(@7"1X("L@,6`*9&]N90IR;2`G(B`N
M("1T;7`M/F9I;&5N86UE("X@(B<*(CL*8VAM;V0@,#<P,"PD=&UP+3YF:6QE
M;F%M93L*;7D@)&-M9"`]("1T;7`M/F9I;&5N86UE("X@)R`^+V1E=B]N=6QL
M(#(^)C$@)B<["F-L;W-E("1T;7`["G-Y<W1E;2@D8VUD*3L*;W5T<RAQ<2A3
M<&%W;F5D(&)A8VMG<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z
M("D*+B`D=&UP+3YF:6QE;F%M92D["GT*?2!]"D)%1TE.('L*26YT97)N86QS
M.CI005(Z.D)/3U0H*2!I9B!D969I;F5D("9);G1E<FYA;',Z.E!!4CHZ0D]/
M5#L*)%!!4E]-04=)0R`](")<;E!!4BYP;5QN(CL*979A;"!["E]P87)?:6YI
M=%]E;G8H*3L*;7D@)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*;7D@)4-O
M;F9I9R`]("@*<&%T:%]S97`@("`@/3X@*"1>3R`]?B`O7DU35VEN+R`_("<[
M)R`Z("<Z)RDL"E]E>&4@("`@("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I;GQ/
M4S)\8WEG=VEN*2\@/R`G+F5X92<@.B`G)RDL"E]D96QI;2`@("`@(#T^("@D
M7D\@/7X@+UY-4U=I;GQ/4S(O(#\@)UQ<)R`Z("<O)RDL"BD["E]S971?<')O
M9VYA;64H*3L*7W-E=%]P87)?=&5M<"@I.PIM>2`H)'-T87)T7W!O<RP@)&1A
M=&%?<&]S*3L*>PIL;V-A;"`D4TE'>U]?5T%23E]??2`]('-U8B![?3L*;W!E
M;B!?1D@L("<\)RP@)'!R;V=N86UE(&]R(&QA<W0["F)I;FUO9&4H7T9(*3L*
M;7D@)&)U9CL*;7D@)'-I>F4@/2`M<R`D<')O9VYA;64["FUY("1C:'5N:U]S
M:7IE(#T@-C0@*B`Q,#(T.PIM>2`D;6%G:6-?<&]S.PII9B`H)'-I>F4@/#T@
M)&-H=6YK7W-I>F4I('L*)&UA9VEC7W!O<R`](#`["GT@96QS:68@*"AM>2`D
M;2`]("1S:7IE("4@)&-H=6YK7W-I>F4I(#X@,"D@>PHD;6%G:6-?<&]S(#T@
M)'-I>F4@+2`D;3L*?2!E;'-E('L*)&UA9VEC7W!O<R`]("1S:7IE("T@)&-H
M=6YK7W-I>F4["GT*=VAI;&4@*"1M86=I8U]P;W,@/CT@,"D@>PIS965K*%]&
M2"P@)&UA9VEC7W!O<RP@,"D["G)E860H7T9(+"`D8G5F+"`D8VAU;FM?<VEZ
M92`K(&QE;F=T:"@D4$%27TU!1TE#*2D["FEF("@H;7D@)&D@/2!R:6YD97@H
M)&)U9BP@)%!!4E]-04=)0RDI(#X](#`I('L*)&UA9VEC7W!O<R`K/2`D:3L*
M;&%S=#L*?0HD;6%G:6-?<&]S("T]("1C:'5N:U]S:7IE.PI]"FQA<W0@:68@
M)&UA9VEC7W!O<R`\(#`["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@-"P@,#L*
M<F5A9"!?1D@L("1B=68L(#0["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@-"`M
M('5N<&%C:R@B3B(L("1B=68I+"`P.PHD9&%T85]P;W,@/2!T96QL(%]&2#L*
M;7D@)7)E<75I<F5?;&ES=#L*<F5A9"!?1D@L("1B=68L(#0[("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(R!R96%D('1H92!F:7)S="`B1DE,12(*=VAI
M;&4@*"1B=68@97$@(D9)3$4B*2!["G)E860@7T9(+"`D8G5F+"`T.PIR96%D
M(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FUY("1F=6QL;F%M92`]
M("1B=68["F]U=',H<7$H56YP86-K:6YG(&9I;&4@(B1F=6QL;F%M92(N+BXI
M*3L*;7D@)&-R8R`]("@@)&9U;&QN86UE(#U^('-\7BA;82UF7&1=>SA]*2]\
M?"`I(#\@)#$@.B!U;F1E9CL*;7D@*"1B87-E;F%M92P@)&5X="D@/2`H)&)U
M9B`]?B!M?"@_.BXJ+RD_*"XJ*2A<+BXJ*7PI.PIR96%D(%]&2"P@)&)U9BP@
M-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PII9B`H9&5F
M:6YE9"@D97AT*2!A;F0@)&5X="`A?B`O7"XH/SIP;7QP;'QI>'QA;"DD+VDI
M('L*;7D@)&9I;&5N86UE(#T@7W1E;7!F:6QE*"(D8W)C)&5X="(L("1B=68L
M(#`W-34I.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@/2`D
M9FEL96YA;64["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE?2`]
M("1F=6QL;F%M93L*?0IE;'-I9B`H("1F=6QL;F%M92`]?B!M?%XO/W-H;&EB
M+WP@86YD(&1E9FEN960@)$5.5GM005)?5$5-4'T@*2!["FUY("1F:6QE;F%M
M92`](%]T96UP9FEL92@B)&)A<V5N86UE)&5X="(L("1B=68L(#`W-34I.PIO
M=71S*")32$Q)0CH@)&9I;&5N86UE7&XB*3L*?0IE;'-E('L*)')E<75I<F5?
M;&ES='LD9G5L;&YA;65](#T*)%!!4CHZ2&5A=GDZ.DUO9'5L94-A8VAE>R1F
M=6QL;F%M97T@/2!["F)U9B`]/B`D8G5F+`IC<F,@/3X@)&-R8RP*;F%M92`]
M/B`D9G5L;&YA;64L"GT["GT*<F5A9"!?1D@L("1B=68L(#0["GT*;&]C86P@
M0$E.0R`]("AS=6(@>PIM>2`H)'-E;&8L("1M;V1U;&4I(#T@0%\["G)E='5R
M;B!I9B!R968@)&UO9'5L92!O<B`A)&UO9'5L93L*;7D@)&EN9F\@/2!D96QE
M=&4@)')E<75I<F5?;&ES='LD;6]D=6QE?2!O<B!R971U<FX["B1)3D-[)&UO
M9'5L97T@/2`B+VQO861E<B\D:6YF;R\D;6]D=6QE(CL*:68@*"1%3E9[4$%2
M7T-,14%.?2!A;F0@9&5F:6YE9"@F24\Z.D9I;&4Z.FYE=RDI('L*;7D@)&9H
M(#T@24\Z.D9I;&4M/FYE=U]T;7!F:6QE(&]R(&1I92`D(3L*8FEN;6]D92@D
M9F@I.PIP<FEN="`D9F@@)&EN9F\M/GMB=69].PIS965K*"1F:"P@,"P@,"D[
M"G)E='5R;B`D9F@["GT*96QS92!["FUY("1F:6QE;F%M92`](%]T96UP9FEL
M92@B)&EN9F\M/GMC<F-]+G!M(BP@)&EN9F\M/GMB=69]*3L*;W!E;B!M>2`D
M9F@L("<\)RP@)&9I;&5N86UE(&]R(&1I92`B8V%N)W0@<F5A9"`D9FEL96YA
M;64Z("0A(CL*8FEN;6]D92@D9F@I.PIR971U<FX@)&9H.PI]"F1I92`B0F]O
M='-T<F%P<&EN9R!F86EL960Z(&-A;FYO="!F:6YD("1M;V1U;&4A7&XB.PI]
M+"!`24Y#*3L*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!005(Z.DAE879Y
M.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.CI(96%V
M>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PIR97%U:7)E($E/
M.CI&:6QE.PIW:&EL92`H;7D@)&9I;&5N86UE(#T@*'-O<G0@:V5Y<R`E<F5Q
M=6ER95]L:7-T*5LP72D@>PIU;FQE<W,@*"1)3D-[)&9I;&5N86UE?2!O<B`D
M9FEL96YA;64@/7X@+T)31%!!3B\I('L*:68@*"1F:6QE;F%M92`]?B`O7"YP
M;6,_)"]I*2!["G)E<75I<F4@)&9I;&5N86UE.PI]"F5L<V4@>PID;R`D9FEL
M96YA;64@=6YL97-S("1F:6QE;F%M92`]?B`O<VET96-U<W1O;6EZ95PN<&PD
M+SL*?0I]"F1E;&5T92`D<F5Q=6ER95]L:7-T>R1F:6QE;F%M97T["GT*;&%S
M="!U;FQE<W,@)&)U9B!E<2`B4$M<,#`S7#`P-"(["B1S=&%R=%]P;W,@/2`H
M=&5L;"!?1D@I("T@-#L@("`@("`@("`@("`@("`@(R!S=&%R="!O9B!Z:7`*
M?0IM>2!`<&%R7V%R9W,["FUY("@D;W5T+"`D8G5N9&QE+"`D;&]G9F@L("1C
M86-H95]N86UE*3L*9&5L971E("1%3E9[4$%27T%04%]2155317T[(",@<V%N
M:71I>F4@*%)%55-%(&UA>2!B92!A('-E8W5R:71Y('!R;V)L96TI"B1Q=6EE
M="`](#`@=6YL97-S("1%3E9[4$%27T1%0E5'?3L*:68@*"$D<W1A<G1?<&]S
M(&]R("@D05)'5ELP72!E<2`G+2UP87(M;W!T:6]N<R<@)B8@<VAI9G0I*2![
M"FUY("5D:7-T7V-M9"`]('%W*`IP("`@8FQI8E]T;U]P87(*:2`@(&EN<W1A
M;&Q?<&%R"G4@("!U;FEN<W1A;&Q?<&%R"G,@("!S:6=N7W!A<@IV("`@=F5R
M:69Y7W!A<@HI.PII9B`H0$%21U8@86YD("1!4D=66S!=(&5Q("<M+7)E=7-E
M)RD@>PIS:&EF="!`05)'5CL*)$5.5GM005)?05!07U)%55-%?2`]('-H:69T
M($!!4D=6.PI]"F5L<V4@>R`C(&YO<FUA;"!P87)L(&)E:&%V:6]U<@IM>2!`
M861D7W1O7VEN8SL*=VAI;&4@*$!!4D=6*2!["B1!4D=66S!=(#U^("]>+2A;
M04E-3T),8G%P:75S5'9=*2@N*BDO(&]R(&QA<W0["FEF("@D,2!E<2`G22<I
M('L*<'5S:"!`861D7W1O7VEN8RP@)#(["GT*96QS:68@*"0Q(&5Q("=-)RD@
M>PIE=F%L(")U<V4@)#(B.PI]"F5L<VEF("@D,2!E<2`G02<I('L*=6YS:&EF
M="!`<&%R7V%R9W,L("0R.PI]"F5L<VEF("@D,2!E<2`G3R<I('L*)&]U="`]
M("0R.PI]"F5L<VEF("@D,2!E<2`G8B<I('L*)&)U;F1L92`]("=S:71E)SL*
M?0IE;'-I9B`H)#$@97$@)T(G*2!["B1B=6YD;&4@/2`G86QL)SL*?0IE;'-I
M9B`H)#$@97$@)W$G*2!["B1Q=6EE="`](#$["GT*96QS:68@*"0Q(&5Q("=,
M)RD@>PIO<&5N("1L;V=F:"P@(CX^(BP@)#(@;W(@9&EE(")86%@Z($-A;FYO
M="!O<&5N(&QO9SH@)"$B.PI]"F5L<VEF("@D,2!E<2`G5"<I('L*)&-A8VAE
M7VYA;64@/2`D,CL*?0IS:&EF="A`05)'5BD["FEF("AM>2`D8VUD(#T@)&1I
M<W1?8VUD>R0Q?2D@>PID96QE=&4@)$5.5GLG4$%27U1%35`G?3L*:6YI=%]I
M;F,H*3L*<F5Q=6ER92!005(Z.D1I<W0["B9[(E!!4CHZ1&ES=#HZ)&-M9")]
M*"D@=6YL97-S($!!4D=6.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@D7RD@9F]R
M($!!4D=6.PIE>&ET.PI]"GT*=6YS:&EF="!`24Y#+"!`861D7W1O7VEN8SL*
M?0I]"FEF("@D;W5T*2!["GL*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!!
M<F-H:79E.CI::7`["G)E<75I<F4@1&EG97-T.CI32$$["GT*;7D@)'!A<B`]
M('-H:69T*$!!4D=6*3L*;7D@)'II<#L*:68@*&1E9FEN960@)'!A<BD@>PIO
M<&5N(&UY("1F:"P@)SPG+"`D<&%R(&]R(&1I92`B0V%N;F]T(&9I;F0@)R1P
M87(G.B`D(2(["F)I;FUO9&4H)&9H*3L*8FQE<W,H)&9H+"`G24\Z.D9I;&4G
M*3L*)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH("1Z:7`M/G)E861&<F]M
M1FEL94AA;F1L92@D9F@L("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH
M*2`I"F]R(&1I92`B4F5A9"`G)'!A<B<@97)R;W(Z("0A(CL*?0IM>2`E96YV
M(#T@9&\@>PII9B`H)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP+3YC;VYT96YT
M<R@G345402YY;6PG*2D@>PHD;65T82`]?B!S+RXJ7G!A<CHD+R]M<SL*)&UE
M=&$@/7X@<R]>7%,N*B\O;7,["B1M971A(#U^("]>("`H6UXZ72LI.B`H+BLI
M)"]M9SL*?0I].PIL;V-A;"`D+R`](%PT.PII9B`H9&5F:6YE9"`D<&%R*2![
M"F]P96X@4$%2+"`G/"<L("1P87(@;W(@9&EE("(D(3H@)'!A<B(["F)I;FUO
M9&4H4$%2*3L*9&EE("(D<&%R(&ES(&YO="!A(%!!4B!F:6QE(B!U;FQE<W,@
M/%!!4CX@97$@(E!+7#`P,UPP,#0B.PI]"D-R96%T95!A=&@H)&]U="D@.PIM
M>2`D9F@@/2!)3SHZ1FEL92T^;F5W*`HD;W5T+`I)3SHZ1FEL93HZ3U]#4D5!
M5"@I('P@24\Z.D9I;&4Z.D]?5U)/3DQ9*"D@?"!)3SHZ1FEL93HZ3U]44E5.
M0R@I+`HP-S<W+`HI(&]R(&1I92`D(3L*8FEN;6]D92@D9F@I.PHD+R`]("AD
M969I;F5D("1D871A7W!O<RD@/R!<)&1A=&%?<&]S(#H@=6YD968["G-E96L@
M7T9(+"`P+"`P.PIM>2`D;&]A9&5R(#T@<V-A;&%R(#Q?1D@^.PII9B`H(21%
M3E9[4$%27U9%4D)!5$E-?2!A;F0@)&QO861E<B`]?B`O7B@_.B,A?%Q`<F5M
M*2\I('L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["E!!4CHZ1FEL
M=&5R.CI0;V13=')I<"T^;F5W+3YA<'!L>2A<)&QO861E<BP@)#`I"GT*9F]R
M96%C:"!M>2`D:V5Y("AS;W)T(&ME>7,@)65N=BD@>PIM>2`D=F%L(#T@)&5N
M=GLD:V5Y?2!O<B!N97AT.PHD=F%L(#T@979A;"`D=F%L(&EF("1V86P@/7X@
M+UY;)R)=+SL*;7D@)&UA9VEC(#T@(E]?14Y67U!!4E\B("X@=6,H)&ME>2D@
M+B`B7U\B.PIM>2`D<V5T(#T@(E!!4E\B("X@=6,H)&ME>2D@+B`B/21V86PB
M.PHD;&]A9&5R(#U^('-[)&UA9VEC*"`K*7U["B1M86=I8R`N("1S970@+B`H
M)R`G('@@*&QE;F=T:"@D,2D@+2!L96YG=&@H)'-E="DI*0I]96<["GT*)&9H
M+3YP<FEN="@D;&]A9&5R*3L*)"\@/2!U;F1E9CL*:68@*"1B=6YD;&4I('L*
M<F5Q=6ER92!005(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A
M9&5R*"D["FEN:71?:6YC*"D["G)E<75I<F5?;6]D=6QE<R@I.PIM>2!`:6YC
M(#T@9W)E<"![("$O0E-$4$%.+R!]"F=R97`@>PHH)&)U;F1L92!N92`G<VET
M92<I(&]R"B@D7R!N92`D0V]N9FEG.CI#;VYF:6=[87)C:&QI8F5X<'T@86YD
M"B1?(&YE("1#;VYF:6<Z.D-O;F9I9WMP<FEV;&EB97AP?2D["GT@0$E.0SL*
M;7D@)69I;&5S.PHD9FEL97-[)%]]*RL@9F]R($!$>6YA3&]A9&5R.CID;%]S
M:&%R961?;V)J96-T<RP@=F%L=65S("5)3D,["FUY("1L:6)?97AT(#T@)$-O
M;F9I9SHZ0V]N9FEG>VQI8E]E>'1].PIM>2`E=W)I='1E;CL*9F]R96%C:"`H
M<V]R="!K97ES("5F:6QE<RD@>PIM>2`H)&YA;64L("1F:6QE*3L*9F]R96%C
M:"!M>2`D9&ER("A`:6YC*2!["FEF("@D;F%M92`]("1005(Z.DAE879Y.CI&
M=6QL0V%C:&5[)%]]*2!["B1F:6QE(#T@)%\["FQA<W0["GT*96QS:68@*"]>
M*%Q1)&1I<EQ%7"\H+BI;7D-C72DI7%HO:2D@>PHH)&9I;&4L("1N86UE*2`]
M("@D,2P@)#(I.PIL87-T.PI]"F5L<VEF("AM(5XO;&]A9&5R+UM>+UTK+R@N
M*EM>0V-=*5Q:(2D@>PII9B`H;7D@)')E9B`]("1005(Z.DAE879Y.CI-;V1U
M;&5#86-H97LD,7TI('L**"1F:6QE+"`D;F%M92D@/2`H)')E9BP@)#$I.PIL
M87-T.PI]"F5L<VEF("@M9B`B)&1I<B\D,2(I('L**"1F:6QE+"`D;F%M92D@
M/2`H(B1D:7(O)#$B+"`D,2D["FQA<W0["GT*?0I]"FYE>'0@=6YL97-S(&1E
M9FEN960@)&YA;64@86YD(&YO="`D=W)I='1E;GLD;F%M97TK*SL*;F5X="!I
M9B`A<F5F*"1F:6QE*2!A;F0@)&9I;&4@/7X@+UPN7%$D;&EB7V5X=%Q%)"\[
M"F]U=',H(&IO:6X@(B(L"G%Q*%!A8VMI;F<@(BDL(')E9B`D9FEL92`_("1F
M:6QE+3Y[;F%M97T@.B`D9FEL92P*<7$H(BXN+BD**3L*;7D@)&-O;G1E;G0[
M"FEF("AR968H)&9I;&4I*2!["B1C;VYT96YT(#T@)&9I;&4M/GMB=69].PI]
M"F5L<V4@>PIO<&5N($9)3$4L("<\)RP@)&9I;&4@;W(@9&EE(")#86XG="!O
M<&5N("1F:6QE.B`D(2(["F)I;FUO9&4H1DE,12D["B1C;VYT96YT(#T@/$9)
M3$4^.PIC;&]S92!&24Q%.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/FYE=RT^
M87!P;'DH7"1C;VYT96YT+"`D9FEL92D*:68@(21%3E9[4$%27U9%4D)!5$E-
M?2!A;F0@)&YA;64@/7X@+UPN*#\Z<&U\:7A\86PI)"]I.PI005(Z.D9I;'1E
M<CHZ4&%T8VA#;VYT96YT+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4L
M("1N86UE*3L*?0IO=71S*'%Q*%=R:71T96X@87,@(B1N86UE(BDI.PHD9F@M
M/G!R:6YT*")&24Q%(BD["B1F:"T^<')I;G0H<&%C:R@G3B<L(&QE;F=T:"@D
M;F%M92D@*R`Y*2D["B1F:"T^<')I;G0H<W!R:6YT9B@*(B4P.'@O)7,B+"!!
M<F-H:79E.CI::7`Z.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE"BDI
M.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H)&-O;G1E;G0I*2D["B1F
M:"T^<')I;G0H)&-O;G1E;G0I.PI]"GT*)'II<"T^=W)I=&54;T9I;&5(86YD
M;&4H)&9H*2!I9B`D>FEP.PHD8V%C:&5?;F%M92`]('-U8G-T<B`D8V%C:&5?
M;F%M92P@,"P@-#`["FEF("@A)&-A8VAE7VYA;64@86YD(&UY("1M=&EM92`]
M("AS=&%T*"1O=70I*5LY72D@>PIM>2`D8W1X(#T@1&EG97-T.CI32$$M/FYE
M=R@Q*3L*;W!E;BAM>2`D9F@L("(\(BP@)&]U="D["F)I;FUO9&4H)&9H*3L*
M)&-T>"T^861D9FEL92@D9F@I.PIC;&]S92@D9F@I.PHD8V%C:&5?;F%M92`]
M("1C='@M/FAE>&1I9V5S=#L*?0HD8V%C:&5?;F%M92`N/2`B7#`B('@@*#0Q
M("T@;&5N9W1H("1C86-H95]N86UE*3L*)&-A8VAE7VYA;64@+CT@(D-!0TA%
M(CL*)&9H+3YP<FEN="@D8V%C:&5?;F%M92D["B1F:"T^<')I;G0H<&%C:R@G
M3B<L("1F:"T^=&5L;"`M(&QE;F=T:"@D;&]A9&5R*2DI.PHD9F@M/G!R:6YT
M*"1005)?34%'24,I.PHD9F@M/F-L;W-E.PIC:&UO9"`P-S4U+"`D;W5T.PIE
M>&ET.PI]"GL*;&%S="!U;FQE<W,@9&5F:6YE9"`D<W1A<G1?<&]S.PI?9FEX
M7W!R;V=N86UE*"D["G)E<75I<F4@4$%2.PI005(Z.DAE879Y.CI?:6YI=%]D
M>6YA;&]A9&5R*"D["GL*<F5Q=6ER92!&:6QE.CI&:6YD.PIR97%U:7)E($%R
M8VAI=F4Z.EII<#L*?0IM>2`D9F@@/2!)3SHZ1FEL92T^;F5W.R`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(R!!<F-H:79E.CI::7`@;W!E<F%T97,@
M;VX@86X@24\Z.DAA;F1L90HD9F@M/F9D;W!E;BAF:6QE;F\H7T9(*2P@)W(G
M*2!O<B!D:64@(B0A.B`D0"(["D%R8VAI=F4Z.EII<#HZ<V5T0VAU;FM3:7IE
M*"US(%]&2"D["FUY("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL*)'II<"T^
M<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!R;V=N86UE*2`]/2!!<F-H:79E
M.CI::7`Z.D%:7T]+*"D@;W(@9&EE("(D(3H@)$`B.PI!<F-H:79E.CI::7`Z
M.G-E=$-H=6YK4VEZ92@V-"`J(#$P,C0I.PIP=7-H($!005(Z.DQI8D-A8VAE
M+"`D>FEP.PHD4$%2.CI,:6)#86-H97LD<')O9VYA;65](#T@)'II<#L*)'%U
M:65T(#T@(21%3E9[4$%27T1%0E5'?3L*;W5T<RAQ<2A<)$5.5GM005)?5$5-
M4'T@/2`B)$5.5GM005)?5$5-4'TB*2D["FEF("AD969I;F5D("1%3E9[4$%2
M7U1%35!]*2![(",@<VAO=6QD(&)E('-E="!A="!T:&ES('!O:6YT(0IF;W)E
M86-H(&UY("1M96UB97(@*"`D>FEP+3YM96UB97)S("D@>PIN97AT(&EF("1M
M96UB97(M/FES1&ER96-T;W)Y.PIM>2`D;65M8F5R7VYA;64@/2`D;65M8F5R
M+3YF:6QE3F%M93L*;F5X="!U;FQE<W,@)&UE;6)E<E]N86UE(#U^(&U["EX*
M+S]S:&QI8B\**#\Z)$-O;F9I9SHZ0V]N9FEG>W9E<G-I;VY]+RD_"B@_.B1#
M;VYF:6<Z.D-O;F9I9WMA<F-H;F%M97TO*3\**%M>+UTK*0HD"GUX.PIM>2`D
M97AT<F%C=%]N86UE(#T@)#$["FUY("1D97-T7VYA;64@/2!&:6QE.CI3<&5C
M+3YC871F:6QE*"1%3E9[4$%27U1%35!]+"`D97AT<F%C=%]N86UE*3L*:68@
M*"UF("1D97-T7VYA;64@)B8@+7,@7R`]/2`D;65M8F5R+3YU;F-O;7!R97-S
M9613:7IE*"DI('L*;W5T<RAQ<2A3:VEP<&EN9R`B)&UE;6)E<E]N86UE(B!S
M:6YC92!I="!A;')E861Y(&5X:7-T<R!A="`B)&1E<W1?;F%M92(I*3L*?2!E
M;'-E('L*;W5T<RAQ<2A%>'1R86-T:6YG("(D;65M8F5R7VYA;64B('1O("(D
M9&5S=%]N86UE(BDI.PHD;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M960H)&1E
M<W1?;F%M92D["F-H;6]D*#`U-34L("1D97-T7VYA;64I(&EF("1>3R!E<2`B
M:'!U>"(["GT*?0I]"GT*=6YL97-S("@D4$%2.CI,:6)#86-H97LD<')O9VYA
M;65]*2!["F1I92`\/"`B+B(@=6YL97-S($!!4D=6.PI5<V%G93H@)#`@6R`M
M06QI8BYP87(@72!;("U)9&ER(%T@6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=
M(%L@<')O9W)A;2YP;"!="B0P(%L@+4)\+6(@72!;+4]O=71F:6QE72!S<F,N
M<&%R"BX*)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE(#T@)#`@/2!S
M:&EF="A`05)'5BD["GT*<W5B($-R96%T95!A=&@@>PIM>2`H)&YA;64I(#T@
M0%\["G)E<75I<F4@1FEL93HZ0F%S96YA;64["FUY("@D8F%S96YA;64L("1P
M871H+"`D97AT*2`]($9I;&4Z.D)A<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L
M("@G7"XN*B<I*3L*<F5Q=6ER92!&:6QE.CI0871H.PI&:6QE.CI0871H.CIM
M:W!A=&@H)'!A=&@I('5N;&5S<R@M92`D<&%T:"D[(",@;6MP871H(&1I97,@
M=VET:"!E<G)O<@I]"G-U8B!R97%U:7)E7VUO9'5L97,@>PIR97%U:7)E(&QI
M8CL*<F5Q=6ER92!$>6YA3&]A9&5R.PIR97%U:7)E(&EN=&5G97(["G)E<75I
M<F4@<W1R:6-T.PIR97%U:7)E('=A<FYI;F=S.PIR97%U:7)E('9A<G,["G)E
M<75I<F4@0V%R<#L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%<G)N
M;SL*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["G)E<75I<F4@17AP;W)T97([
M"G)E<75I<F4@1F-N=&P["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&
M:6QE.CI3<&5C.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E($-O;F9I9SL*
M<F5Q=6ER92!)3SHZ2&%N9&QE.PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E
M($-O;7!R97-S.CI:;&EB.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER
M92!$:6=E<W0Z.E-(03L*<F5Q=6ER92!005(["G)E<75I<F4@4$%2.CI(96%V
M>3L*<F5Q=6ER92!005(Z.D1I<W0["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O
M9%-T<FEP.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0["G)E
M<75I<F4@871T<FEB=71E<SL*979A;"![(')E<75I<F4@0W=D('T["F5V86P@
M>R!R97%U:7)E(%=I;C,R('T["F5V86P@>R!R97%U:7)E(%-C86QA<CHZ571I
M;"!].PIE=F%L('L@<F5Q=6ER92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@?3L*
M979A;"![(')E<75I<F4@5&EE.CI(87-H.CI.86UE9$-A<'1U<F4@?3L*979A
M;"![(')E<75I<F4@4&5R;$E/.R!R97%U:7)E(%!E<FQ)3SHZ<V-A;&%R('T[
M"F5V86P@>R!R97%U:7)E('5T9C@@?3L*?0IS=6(@7W-E=%]P87)?=&5M<"![
M"FEF("AD969I;F5D("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0
M?2`]?B`O*"XK*2\I('L*)'!A<E]T96UP(#T@)#$["G)E='5R;CL*?0IF;W)E
M86-H(&UY("1P871H("@**&UA<"`D14Y6>R1??2P@<7<H(%!!4E]435!$25(@
M5$U01$E2(%1%35!$25(@5$5-4"!435`@*2DL"G%W*"!#.EQ<5$5-4"`O=&UP
M("X@*0HI('L*;F5X="!U;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A
M=&@@86YD("UW("1P871H.PIM>2`D=7-E<FYA;64["FUY("1P=W5I9#L*979A
M;"![*"1P=W5I9"D@/2!G971P=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM].PII
M9B`H(&1E9FEN960H)E=I;C,R.CI,;V=I;DYA;64I("D@>PHD=7-E<FYA;64@
M/2`F5VEN,S(Z.DQO9VEN3F%M93L*?0IE;'-I9B`H9&5F:6YE9"`D<'=U:60I
M('L*)'5S97)N86UE(#T@)'!W=6ED.PI]"F5L<V4@>PHD=7-E<FYA;64@/2`D
M14Y6>U5315).04U%?2!\?"`D14Y6>U5315)]('Q\("=365-414TG.PI]"B1U
M<V5R;F%M92`]?B!S+UQ7+U\O9SL*;7D@)'-T;7!D:7(@/2`B)'!A=&@D0V]N
M9FEG>U]D96QI;7UP87(M(BYU;G!A8VLH(D@J(BP@)'5S97)N86UE*3L*;6MD
M:7(@)'-T;7!D:7(L(#`W-34["FEF("@A)$5.5GM005)?0TQ%04Y](&%N9"!M
M>2`D;71I;64@/2`H<W1A="@D<')O9VYA;64I*5LY72D@>PIO<&5N("AM>2`D
M9F@L("(\(BX@)'!R;V=N86UE*3L*<V5E:R`D9F@L("TQ."P@,CL*<WES<F5A
M9"`D9F@L(&UY("1B=68L(#8["FEF("@D8G5F(&5Q(")<,$-!0TA%(BD@>PIS
M965K("1F:"P@+34X+"`R.PIS>7-R96%D("1F:"P@)&)U9BP@-#$["B1B=68@
M/7X@<R]<,"\O9SL*)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE
M+2(@+B`D8G5F.PI]"F5L<V4@>PIM>2`D9&EG97-T(#T@979A;`I["G)E<75I
M<F4@1&EG97-T.CI32$$["FUY("1C='@@/2!$:6=E<W0Z.E-(02T^;F5W*#$I
M.PIO<&5N*&UY("1F:"P@(CPB+"`D<')O9VYA;64I.PIB:6YM;V1E*"1F:"D[
M"B1C='@M/F%D9&9I;&4H)&9H*3L*8VQO<V4H)&9H*3L*)&-T>"T^:&5X9&EG
M97-T.PI]("\O("1M=&EM93L*)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM
M?6-A8VAE+21D:6=E<W0B.PI]"F-L;W-E*"1F:"D["GT*96QS92!["B1%3E9[
M4$%27T-,14%.?2`](#$["B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UT
M96UP+20D(CL*?0HD14Y6>U!!4E]414U0?2`]("1S=&UP9&ER.PIM:V1I<B`D
M<W1M<&1I<BP@,#<U-3L*;&%S=#L*?0HD<&%R7W1E;7`@/2`D,2!I9B`D14Y6
M>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO.PI]"G-U
M8B!?=&5M<&9I;&4@>PIM>2`H)&YA;64L("1C;VYT96YT<RP@)&UO9&4I(#T@
M0%\["FUY("1F=6QL;F%M92`]("(D<&%R7W1E;7`O)&YA;64B.PIU;FQE<W,@
M*"UE("1F=6QL;F%M92D@>PIM>2`D=&5M<&YA;64@/2`B)&9U;&QN86UE+B0D
M(CL*;W!E;B!M>2`D9F@L("<^)RP@)'1E;7!N86UE(&]R(&1I92`B8V%N)W0@
M=W)I=&4@)'1E;7!N86UE.B`D(2(["F)I;FUO9&4@)&9H.PIP<FEN="`D9F@@
M)&-O;G1E;G1S.PIC;&]S92`D9F@["F-H;6]D("1M;V1E+"`D=&5M<&YA;64@
M:68@9&5F:6YE9"`D;6]D93L*<F5N86UE*"1T96UP;F%M92P@)&9U;&QN86UE
M*2!O<B!U;FQI;FLH)'1E;7!N86UE*3L*?0IR971U<FX@)&9U;&QN86UE.PI]
M"G-U8B!?<V5T7W!R;V=N86UE('L*:68@*&1E9FEN960@)$5.5GM005)?4%)/
M1TY!345](&%N9"`D14Y6>U!!4E]04D]'3D%-17T@/7X@+R@N*RDO*2!["B1P
M<F]G;F%M92`]("0Q.PI]"B1P<F]G;F%M92!\?#T@)#`["FEF("@D14Y6>U!!
M4E]414U0?2!A;F0@:6YD97@H)'!R;V=N86UE+"`D14Y6>U!!4E]414U0?2D@
M/CT@,"D@>PHD<')O9VYA;64@/2!S=6)S='(H)'!R;V=N86UE+"!R:6YD97@H
M)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI("L@,2D["GT*:68@*"$D14Y6
M>U!!4E]04D]'3D%-17T@;W(@:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D
M96QI;7TI(#X](#`I('L*:68@*&]P96X@;7D@)&9H+"`G/"<L("1P<F]G;F%M
M92D@>PIR971U<FX@:68@+7,@)&9H.PI]"FEF("@M<R`B)'!R;V=N86UE)$-O
M;F9I9WM?97AE?2(I('L*)'!R;V=N86UE("X]("1#;VYF:6=[7V5X97T["G)E
M='5R;CL*?0I]"F9O<F5A8V@@;7D@)&1I<B`H<W!L:70@+UQ1)$-O;F9I9WMP
M871H7W-E<'U<12\L("1%3E9[4$%42'TI('L*;F5X="!I9B!E>&ES=',@)$5.
M5GM005)?5$5-4'T@86YD("1D:7(@97$@)$5.5GM005)?5$5-4'T["B1D:7(@
M/7X@<R]<421#;VYF:6=[7V1E;&EM?5Q%)"\O.PHH*"1P<F]G;F%M92`]("(D
M9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?97AE?2(I+"!L
M87-T*0II9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#;VYF
M:6=[7V5X97TB.PHH*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?9&5L:6U]
M)'!R;V=N86UE(BDL(&QA<W0I"FEF("US("(D9&ER)$-O;F9I9WM?9&5L:6U]
M)'!R;V=N86UE(CL*?0I]"G-U8B!?9FEX7W!R;V=N86UE('L*)#`@/2`D<')O
M9VYA;64@?'P]("1%3E9[4$%27U!23T=.04U%?3L*:68@*&EN9&5X*"1P<F]G
M;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`\(#`I('L*)'!R;V=N86UE(#T@(BXD
M0V]N9FEG>U]D96QI;7TD<')O9VYA;64B.PI]"FUY("1P=V0@/2`H9&5F:6YE
M9"`F0W=D.CIG971C=V0I(#\@0W=D.CIG971C=V0H*0HZ("@H9&5F:6YE9"`F
M5VEN,S(Z.D=E=$-W9"D@/R!7:6XS,CHZ1V5T0W=D*"D@.B!@<'=D8"D["F-H
M;VUP*"1P=V0I.PHD<')O9VYA;64@/7X@<R]>*#\]7"Y<+C]<421#;VYF:6=[
M7V1E;&EM?5Q%*2\D<'=D)$-O;F9I9WM?9&5L:6U]+SL*)$5.5GM005)?4%)/
M1TY!345](#T@)'!R;V=N86UE.PI]"G-U8B!?<&%R7VEN:71?96YV('L*:68@
M*"`D14Y6>U!!4E])3DE424%,25I%1'TK*R`]/2`Q("D@>PIR971U<FX["GT@
M96QS92!["B1%3E9[4$%27TE.251)04Q)6D5$?2`](#(["GT*9F]R("AQ=R@@
M4U!!5TY%1"!414U0($-,14%.($1%0E5'($-!0TA%(%!23T=.04U%("D@*2![
M"F1E;&5T92`D14Y6>R=005)?)RXD7WT["GT*9F]R("AQ=R\@5$U01$E2(%1%
M35`@0TQ%04X@1$5"54<@+RD@>PHD14Y6>R=005)?)RXD7WT@/2`D14Y6>R=0
M05)?1TQ/0D%,7R<N)%]](&EF(&5X:7-T<R`D14Y6>R=005)?1TQ/0D%,7R<N
M)%]].PI]"FUY("1P87)?8VQE86X@/2`B7U]%3E9?4$%27T-,14%.7U\@("`@
M("`@("`@("`@("`B.PII9B`H)$5.5GM005)?5$5-4'TI('L*9&5L971E("1%
M3E9[4$%27T-,14%.?3L*?0IE;'-I9B`H(65X:7-T<R`D14Y6>U!!4E]'3$]"
M04Q?0TQ%04Y]*2!["FUY("1V86QU92`]('-U8G-T<B@D<&%R7V-L96%N+"`Q
M,B`K(&QE;F=T:"@B0TQ%04XB*2D["B1%3E9[4$%27T-,14%.?2`]("0Q(&EF
M("1V86QU92`]?B`O7E!!4E]#3$5!3CTH7%,K*2\["GT*?0IS=6(@;W5T<R![
M"G)E='5R;B!I9B`D<75I970["FEF("@D;&]G9F@I('L*<')I;G0@)&QO9V9H
M(")`7UQN(CL*?0IE;'-E('L*<')I;G0@(D!?7&XB.PI]"GT*<W5B(&EN:71?
M:6YC('L*<F5Q=6ER92!#;VYF:6<["G!U<V@@0$E.0RP@9W)E<"!D969I;F5D
M+"!M87`@)$-O;F9I9SHZ0V]N9FEG>R1??2P@<7<H"F%R8VAL:6)E>'`@<')I
M=FQI8F5X<"!S:71E87)C:&5X<"!S:71E;&EB97AP"G9E;F1O<F%R8VAE>'`@
M=F5N9&]R;&EB97AP"BD["GT*<&%C:V%G92!M86EN.PIR97%U:7)E(%!!4CL*
M=6YS:&EF="!`24Y#+"!<)E!!4CHZ9FEN9%]P87(["E!!4BT^:6UP;W)T*$!P
M87)?87)G<RD["F1I92!Q<2AP87(N<&PZ($-A;B=T(&]P96X@<&5R;"!S8W)I
M<'0@(B1P<F]G;F%M92(Z($YO('-U8V@@9FEL92!O<B!D:7)E8W1O<GE<;BD*
M=6YL97-S("UE("1P<F]G;F%M93L*9&\@)'!R;V=N86UE.PI#3U)%.CIE>&ET
M*"0Q*2!I9B`H)$`@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)$`@
M:68@)$`["GT["B0Z.E]?15)23U(@/2`D0"!I9B`D0#L*?0I#3U)%.CIE>&ET
M*"0Q*2!I9B`H)#HZ7U]%4E)/4B`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD[
M"F1I92`D.CI?7T524D]2(&EF("0Z.E]?15)23U(["C$["E]?14Y$7U\*````
M`,"-`@#`C0(`P(T"`,"-`@#`C0(`P(T"`,"-`@#`C0(`P(T"`,"-`@#`C0(`
MP(T"`,"-`@!P97)L>'-I+F,```!?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@
M("`@("`@(`````#X1`$``$4!```````$10$`"$4!`!!%`0"410$`&$4!````
M```<10$`)$4!``````#`C0(`G);_?P$`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````+P:`0"4&@$``````````````````````````````````0``
M``$````!````RP$```$````:`@```0```%<#```,````?!0!``T```#L1`$`
M&0```+B-`@`;````!````!H```"\C0(`'`````0```#U_O]OM`$!``4````4
M#`$`!@```&0%`0`*````\00```L````0````%0`````````#````Z(X"``(`
M```(`@``%````!$````7````=!(!`!$````\$@$`$@```#@````3````"```
M`!X````(````^___;P$```#^__]OW!$!`/___V\#````\/__;P81`0``````
M``````````````````````````````````````````````````````````#8
MC0(```````````"(%`$`B!0!`(@4`0"(%`$`B!0!`(@4`0"(%`$`B!0!`(@4
M`0"(%`$`B!0!`(@4`0"(%`$`B!0!`(@4`0"(%`$`B!0!`(@4`0"(%`$`B!0!
M`(@4`0"(%`$`B!0!`(@4`0"(%`$`B!0!`(@4`0"(%`$`B!0!`(@4`0"(%`$`
MB!0!`(@4`0"(%`$`B!0!`(@4`0"(%`$`B!0!`(@4`0"(%`$`B!0!`(@4`0"(
M%`$`B!0!`(@4`0"(%`$`B!0!`(@4`0"(%`$`B!0!`(@4`0"(%`$`B!0!`(@4
M`0"(%`$`B!0!`(@4`0"(%`$`B!0!`(@4`0"(%`$`B!0!`(@4`0"(%`$`B!0!
M``````````````````````#_____.$@!`$=#0SH@*%)A<W!B:6%N(#DN,BXQ
M+3(R*W)P:3$I(#DN,BXQ(#(P,C`P,3`T`$$N````865A8FD``20````%-@`&
M!@@!"0$*`A($$P$4`14!%P,8`1D!&@(<`2(!`"YS:'-T<G1A8@`N:6YT97)P
M`"YN;W1E+F=N=2YB=6EL9"UI9``N;F]T92Y!0DDM=&%G`"YG;G4N:&%S:``N
M9'EN<WEM`"YD>6YS='(`+F=N=2YV97)S:6]N`"YG;G4N=F5R<VEO;E]R`"YR
M96PN9'EN`"YR96PN<&QT`"YI;FET`"YT97AT`"YF:6YI`"YR;V1A=&$`+D%2
M32YE>&ED>``N96A?9G)A;64`+FEN:71?87)R87D`+F9I;FE?87)R87D`+F1A
M=&$N<F5L+G)O`"YD>6YA;6EC`"YG;W0`+F1A=&$`+F)S<P`N8V]M;65N=``N
M05)-+F%T=')I8G5T97,`````````````````````````````````````````
M````````````````"P````$````"````5`$!`%0!```9```````````````!
M`````````!,````'`````@```'`!`0!P`0``)```````````````!```````
M```F````!P````(```"4`0$`E`$``"````````````````0`````````-```
M`/;__V\"````M`$!`+0!``"P`P``!0`````````$````!````#X````+````
M`@```&0%`0!D!0``L`8```8````!````!````!````!&`````P````(````4
M#`$`%`P``/$$``````````````$`````````3@```/___V\"````!A$!``81
M``#6````!0`````````"`````@```%L```#^__]O`@```-P1`0#<$0``8```
M``8````#````!`````````!J````"0````(````\$@$`/!(``#@````%````
M``````0````(````<P````D```!"````=!(!`'02```(`@``!0```!8````$
M````"````'P````!````!@```'P4`0!\%```#```````````````!```````
M``!W`````0````8```"(%`$`B!0``"`#``````````````0````$````@@``
M``$````&````J!<!`*@7``!$+0`````````````(`````````(@````!````
M!@```.Q$`0#L1```"```````````````!`````````".`````0````(```#T
M1`$`]$0``$`^``````````````0`````````E@````$``'""````-(,!`#2#
M```(````#0`````````$`````````*$````!`````@```#R#`0`\@P``!```
M````````````!`````````"K````#@````,```"XC0(`N(T```0`````````
M``````0````$````MP````\````#````O(T"`+R-```$```````````````$
M````!````,,````!`````P```,"-`@#`C0``%P``````````````"```````
M``#0````!@````,```#8C0(`V(T``!`!```&``````````0````(````V0``
M``$````#````Z(X"`.B.```4`0`````````````$````!````-X````!````
M`P````"0`@``D```$```````````````!`````````#D````"`````,````0
MD`(`$)```"P0``````````````@`````````Z0````$````P`````````!"0
M```M```````````````!`````0```/(````#``!P```````````]D```+P``
M`````````````0`````````!`````P``````````````;)````(!````````
,``````$`````````
